@@ -677,10 +677,8 @@
     </message>
     <message>
         <location filename="../../fpwin.cpp" line="100"/>
-        <source>Calculate number of words
-(For huge texts, this may be CPU-intensive.)</source>
-        <translation>Loe kokku sõnade arv
-(mahuka teksti puhul see tekitab protsessorikoormust)</translation>
+        <source>Calculate number of words</source>
+        <translation>Loe kokku sõnade arv</translation>
     </message>
     <message>
         <location filename="../../fpwin.cpp" line="115"/>
@@ -1507,7 +1505,7 @@ eraldi faili avamise vaade on olemas (näiteks KDE ja LXQt).</translation>
 and a double hyphen with a long dash while typing,
 under proper circumstances.</source>
         <translation>Kui kõik klapib, siis vaikimisi asendame
-kolm punkti (...) mõttepunktiga (...) ja 
+kolm punkti (...) mõttepunktiga (...) ja
 kaks sidekriipsu (--) mõttekriipsuga (—).</translation>
     </message>
     <message>
@@ -1519,7 +1517,7 @@ kaks sidekriipsu (--) mõttekriipsuga (—).</translation>
         <location filename="../../prefDialog.ui" line="541"/>
         <source>Highlight case-sensitive and whole matches
 of the selected text.</source>
-        <translation>Tõsta esile tõstutundliku ja täissõna 
+        <translation>Tõsta esile tõstutundliku ja täissõna
 otsingu tulemused.</translation>
     </message>
     <message>
@@ -1548,7 +1546,7 @@ nupu süntaksivaliku muutmiseks.</translation>
         <location filename="../../prefDialog.ui" line="646"/>
         <source>Show spaces, tabs and tab lines
 when the syntax is highlighted.</source>
-        <translation>Süntaksi esiletõstmisel näita tühikuid, 
+        <translation>Süntaksi esiletõstmisel näita tühikuid,
 tabulaatoreid ja tabulaatorijooni.</translation>
     </message>
     <message>
@@ -1561,7 +1559,7 @@ tabulaatoreid ja tabulaatorijooni.</translation>
         <location filename="../../prefDialog.ui" line="677"/>
         <source>The vertical position lines will be drawn only if
 the editor font has a fixed pitch (like Monospace).</source>
-        <translation>Püstist piirjoont saame kuvada vaid siis, kui sa oled kasutatavaks 
+        <translation>Püstist piirjoont saame kuvada vaid siis, kui sa oled kasutatavaks
 kirjatüübiks määranud fikseeritud laiusega fondi (nagu näiteks Monospace).</translation>
     </message>
     <message>
@@ -1750,7 +1748,7 @@ process could be killed by Ctrl+Alt+E.</source>
 kirjutatud mõnes kestakeeles või Pythonis.
 
 Kui see valik on kasutusel ja avatud fail on
-käivitatav, siis menüüsse ja tööriistaribale 
+käivitatav, siis menüüsse ja tööriistaribale
 ilmuvast Käivita nupust saad ta tööle panna.
 Samuti võid käivitamiseks kasutada Ctrl+E kiirklahvi.
 Skripti töö saad lõpetada Ctrl+Alt+E kiirklahviga.</translation>
@@ -1778,7 +1776,7 @@ Heleda tausta jaoks sobib
 230 kuni 255 vahemik ja tumeda
 tausta jaoks sobib 0 kuni 50 vahemik.
 
-Selle muudatuse jõustamiseks pead 
+Selle muudatuse jõustamiseks pead
 rakenduse akna uuesti avama.</translation>
     </message>
     <message>
@@ -1862,7 +1860,7 @@ failis ning tema kõrval peab olema sama nimega ja
     </message>
     <message>
         <location filename="../../prefDialog.ui" line="937"/>
-        <location filename="../../pref.cpp" line="1800"/>
+        <location filename="../../pref.cpp" line="1802"/>
         <source>Add dictionary...</source>
         <translation>Lisa sõnastik...</translation>
     </message>
@@ -2011,123 +2009,123 @@ avab selle kopeeritud faili.</translation>
         <translation>Sulge</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="111"/>
+        <location filename="../../pref.cpp" line="113"/>
         <source>Press a modifier key to clear a shortcut
 in the editing mode.</source>
         <translation>Muutmisvaates vajuta kiirklahvi
 kustutamiseks muuteklahvi.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="117"/>
+        <location filename="../../pref.cpp" line="119"/>
         <source>Double click a color to change it.</source>
         <translation>Värvi muutmiseks tee topeltklõps.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="353"/>
-        <location filename="../../pref.cpp" line="1496"/>
+        <location filename="../../pref.cpp" line="355"/>
+        <location filename="../../pref.cpp" line="1498"/>
         <source>files</source>
         <translation>failid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="353"/>
-        <location filename="../../pref.cpp" line="1496"/>
+        <location filename="../../pref.cpp" line="355"/>
+        <location filename="../../pref.cpp" line="1498"/>
         <source>file</source>
         <translation>fail</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="420"/>
-        <location filename="../../pref.cpp" line="1615"/>
+        <location filename="../../pref.cpp" line="422"/>
+        <location filename="../../pref.cpp" line="1617"/>
         <source>Warning: Ambiguous shortcut detected!</source>
         <translation>Hoiatus: sama kombinatsioon on kasutusel mitmel kiirklahvil!</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="453"/>
+        <location filename="../../pref.cpp" line="455"/>
         <source>Functions, URLs,…</source>
         <translation>Funktsioonid, URLid,…</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="454"/>
+        <location filename="../../pref.cpp" line="456"/>
         <source>Built-in Functions</source>
         <translation>Funktsioonid antud keeles</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="455"/>
+        <location filename="../../pref.cpp" line="457"/>
         <source>Comments</source>
         <translation>Kommentaarid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="456"/>
+        <location filename="../../pref.cpp" line="458"/>
         <source>Quotations</source>
         <translation>Tsitaadid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="457"/>
+        <location filename="../../pref.cpp" line="459"/>
         <source>Types</source>
         <translation>Andmetüübid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="458"/>
+        <location filename="../../pref.cpp" line="460"/>
         <source>Key Words</source>
         <translation>Võtmesõnad</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="459"/>
+        <location filename="../../pref.cpp" line="461"/>
         <source>Numbers</source>
         <translation>Arvud</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="460"/>
+        <location filename="../../pref.cpp" line="462"/>
         <source>Regular Expressions, Code Blocks,…</source>
         <translation>Regulaaravaldised, koodiblokid, …</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="461"/>
+        <location filename="../../pref.cpp" line="463"/>
         <source>Document Blocks, XML/HTML Elements,…</source>
         <translation>Dokumendiblokid, XML&apos;i ja HTML&apos;i elemendid, …</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="462"/>
+        <location filename="../../pref.cpp" line="464"/>
         <source>Markdown Headings, CSS Values,…</source>
         <translation>Pealkirjad Markdown-märgistuses, CSS väärtused, …</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="463"/>
+        <location filename="../../pref.cpp" line="465"/>
         <source>Extra Elements</source>
         <translation>Muud elemendid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="645"/>
+        <location filename="../../pref.cpp" line="647"/>
         <source>Application restart is needed for changes to take effect.</source>
         <translation>Selle muudatuse jõustamiseks pead rakenduse uuesti käivitama.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="666"/>
+        <location filename="../../pref.cpp" line="668"/>
         <source>Window reopening is needed for changes to take effect.</source>
         <translation>Selle muudatuse jõustamiseks pead rakenduse akna uuesti avama.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="1522"/>
+        <location filename="../../pref.cpp" line="1524"/>
         <source>&amp;Recently Opened</source>
         <translation>&amp;Hiljuti avatud</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="1523"/>
+        <location filename="../../pref.cpp" line="1525"/>
         <source>Recently &amp;Modified</source>
         <translation>Hiljuti &amp;muudetud failid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="1598"/>
+        <location filename="../../pref.cpp" line="1600"/>
         <source>The typed shortcut was reserved.</source>
         <translation>Sisestatud kiirklahv on reserveeritud muuks kasutuseks.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="1802"/>
+        <location filename="../../pref.cpp" line="1804"/>
         <source>Hunspell Dictionary Files</source>
         <translation>Hunspell&apos;i sõnastikufailid</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="521"/>
-        <location filename="../../pref.cpp" line="1888"/>
+        <location filename="../../pref.cpp" line="523"/>
+        <location filename="../../pref.cpp" line="1890"/>
         <source>Select Syntax Color</source>
         <translation>Vali süntaksivärv</translation>
     </message>
@@ -2365,7 +2363,7 @@ kõik failid kõikides avatud akendes.</translation>
 <context>
     <name>FeatherPad::TextEdit</name>
     <message>
-        <location filename="../../textedit.cpp" line="149"/>
+        <location filename="../../textedit.cpp" line="152"/>
         <source>Double click to center current line</source>
         <translation>Rea joondamiseks keskele topeltklõpsa</translation>
     </message>
